@@ -11,6 +11,7 @@ from django_cloud_tasks import exceptions
 
 
 class DjangoCloudTasksAppConfig(AppConfig):
+    default_auto_field = "django.db.models.AutoField"
     name = "django_cloud_tasks"
     verbose_name = "Django Cloud Tasks"
 
@@ -101,3 +102,6 @@ class DjangoCloudTasksAppConfig(AppConfig):
                     removed.append(subscribed_task)
 
         return updated, removed
+
+    def ready(self):
+        from django_cloud_tasks import signals  # pylint: disable=import-outside-toplevel,unused-import
